.. _urlpublishing_module:

:mod:`cubicweb.web.views.urlpublishing`
=======================================

.. automodule:: cubicweb.web.views.urlpublishing

    .. autoexception:: PathDontMatch

    .. autoclass:: URLPublisherComponent
        :show-inheritance:
        :members:

    .. autoclass:: URLPathEvaluator
        :show-inheritance:
        :members:

    .. autoclass:: RawPathEvaluator
        :show-inheritance:
        :members:

    .. autoclass:: EidPathEvaluator
        :show-inheritance:
        :members:

    .. autoclass:: RestPathEvaluator
        :show-inheritance:
        :members:

    .. autoclass:: URLRewriteEvaluator
        :show-inheritance:
        :members:

    .. autoclass:: ActionPathEvaluator
        :show-inheritance:
        :members:
